function info = fcnEval( opts )
%FCNEVAL segment and image using trained net
% Evaluate image, return binary image. Trained net classify all image
% pixels as 1: ROI or 0: NON-ROI.

% Load vlfeat and matconvnet tools
start;

% set output folder
targetFolder = fullfile( opts.outputFolder, 'eval');
if ~exist(opts.outputFolder, 'dir'), mkdir(opts.outputFolder); end
if ~exist(targetFolder, 'dir'), mkdir(targetFolder); end

% -------------------------------------------------------------------------
% Setup model
% -------------------------------------------------------------------------
    
    % Load trained net
    count = fprintf('\nLoading net ........ BUSY');
    net = load(fullfile(opts.paths.net, opts.netName));
    fprintf(1, repmat('\b',1,count-1)); %delete line before
    fprintf('Loading net ........ DONE!\n');
    
    % setup net as DaG network
    net = dagnn.DagNN.loadobj(net.net) ;
    net.mode = 'test' ;
    % remove layers used at training process 
    for name = {'objective', 'accuracy'}
      net.removeLayer(name) ;
    end
    
    net.meta.normalization.averageImage = reshape(net.meta.normalization.rgbMean,1,1,3) ;
    predVar = net.getVarIndex('prediction') ;
    inputVar = 'input' ;
    imageNeedsToBeMultiple = true ;
    
    % Set GPU
    if opts.usegpu
        count = fprintf('Setting GPU ........... BUSY\n');
        gpuDevice(1); net.move('gpu') 
        fprintf(1, repmat('\b',1,count)); %delete line before
        fprintf('Setting GPU ........... DONE!\n');
    end;
    
    % Load image
    image = imread(fullfile(opts.filepath, opts.filename)) ;
        
    % Subtract the mean (color)
    im = bsxfun(@minus, single(image), net.meta.normalization.averageImage);
    
    % Some networks requires the image to be a multiple of 32 pixels
    if imageNeedsToBeMultiple
      sz = [size(im,1), size(im,2)] ;
      sz_ = round(sz / 32)*32 ;
      im_ = imresize(im, sz_) ;
    else
      im_ = im ;
    end
    
    if opts.usegpu, im_ = gpuArray(im_) ; end
    
    % compute scores from net and sample
    count = fprintf('Computing .......... BUSY\n');
    net.eval({inputVar, im_}) ;
    scores_ = gather(net.vars(predVar).value) ;
    [~,pred_] = max(scores_,[],3) ;

    if imageNeedsToBeMultiple
      pred = imresize(pred_, sz, 'method', 'nearest') ;
    else
      pred = pred_ ;
    end
    fprintf(1, repmat('\b',1,count)); %delete line before
    fprintf('Computing .......... DONE!\n');
    
    % plot and Save segmentation
    [~, name, ~] = fileparts(opts.filename);
    imPath = fullfile(targetFolder, [name '_segmentation.png']) ;
    figure;
    subplot(1,2,1);
    imshow(image);
    subplot(1,2,2);
    imshow(pred-2);
    imwrite((pred-2),imPath,'png');
end

