function fcnTrainBinaryModel( varargin )
%FCNTRAINBINARYMODEL Train FCN model using MatConvNet

% Adapt original fncTrain to binary classification.

% Load vlfeat and matconvnet tools
start;

% set experiment data paths and parse variables
opts.expDir = [] ;
opts.dataDir = [] ;
opts.model = [] ;
opts.epochs = [];
opts.imdbPath = [];
opts.modelType = [] ;
opts.learningRate = [];
opts.useGPU = false;
opts.imageSize= [];
opts.fc8factor = 1;
opts.plotStatistics = true;
opts.storeAllEpochs = true;
% parse
opts = vl_argparse(opts, varargin) ;


% set gpu usage
if opts.useGPU, gpu = 1;else, gpu = []; end
% set stats file
imdbStatsPath = fullfile(opts.expDir, 'imdbStats.mat') ;

% load imdb
imdb = load(opts.imdbPath);

% training options (SGD)
trainOpts = struct(...
    'batchSize', 10,...
    'numSubBatches', 10,...
    'continue' , true,...
    'gpus', gpu,...
    'prefetch', true,...
    'expDir' , opts.expDir,...
    'learningRate',  opts.learningRate * ones(1,opts.epochs),...
    'numEpochs', opts.epochs,...
    'plotStatistics', opts.plotStatistics,...
    'storeAllEpochs', opts.storeAllEpochs);

% -------------------------------------------------------------------------
% Setup data
% -------------------------------------------------------------------------

% Get training and test/validation subsets
trainSet = find(imdb.images.set == 1 & imdb.images.segmentation) ;
valSet = find(imdb.images.set == 2 & imdb.images.segmentation) ;

% Get dataset statistics
if exist(imdbStatsPath, 'file')
  stats = load(imdbStatsPath) ;
else
  stats = getDatasetStatisticsBinModel(imdb) ;
  save(imdbStatsPath, '-struct', 'stats') ;
end
% -------------------------------------------------------------------------
% Setup model
% -------------------------------------------------------------------------

% Get initial model from VGG-VD-16
url = ...
    'http://www.vlfeat.org/matconvnet/models/imagenet-vgg-verydeep-16.mat';
 
net = fcnInitializeBinaryModel(...
    'sourceModelPath', opts.model,...
    'sourceModelUrl', url);

if any(strcmp(opts.modelType, {'fcn16s', 'fcn8s'}))
  % upgrade model to FCN16s
  net = fcnInitializeBinaryModel16s(net) ;
end

if strcmp(opts.modelType, 'fcn8s')
  % upgrade model to FCN8s
  net = fcnInitializeBinaryModel8s(net) ;
end

net.meta.normalization.rgbMean = stats.rgbMean ;
net.meta.classes = imdb.classes.name ;

% fine tune learning rate

setLRFactor (net, 'fc8', opts.fc8factor);

% -------------------------------------------------------------------------
% Train
% -------------------------------------------------------------------------

% Setup data fetching options
bopts.labelStride = 1 ;
bopts.labelOffset = 1 ;
bopts.classWeights = ones(1,2,'single') ;
bopts.rgbMean = stats.rgbMean ;
bopts.imageSize = opts.imageSize;
if opts.useGPU, bopts.gpu = 1 ; end

% Launch SGD
info = cnn_train_dagBM(net, imdb, getBatchWrapper(bopts), ...
                     trainOpts, ....
                     'train', trainSet, ...
                     'val', valSet, ...
                     trainOpts) ;
                 
 %clearvars net;
 %clearvars imdb;
% -------------------------------------------------------------------------
function fn = getBatchWrapper(opts)
% -------------------------------------------------------------------------
fn = @(imdb,batch) getBatchBinModel(imdb,batch,opts,'prefetch',nargout==0);

%--------------------------------------------------------------------------
% set Learning rate multiplying factor
%--------------------------------------------------------------------------
function setLRFactor (net, layerName, lrfactor) 
% layerName = Name of the target layer we want to fine tune
% lrfactor = multiplier learning rate factor. 10 means lr x 10 
% find layer index in the DagNN

layerIndex = net.getLayerIndex(layerName);
    
% find the parameter names for the layer
paramNames = [net.layers(layerIndex).params];

% find the indices of these parameters 
paramIdx = net.getParamIndex(paramNames);
    
% Filter
[net.params(paramIdx(1)).learningRate] = deal(lrfactor);
% Bias
[net.params(paramIdx(2)).learningRate] = deal(lrfactor*2);

