function stats = getDatasetStatisticsBinModel(imdb)

% read segmentation and data indexs from training set 
segTrain = find(imdb.images.set == 1 & imdb.images.segmentation) ;
dataTrain = find(imdb.images.set == 1 & imdb.images.classification) ;

% Class statistics
numClasses = 3; % three classes, Background, ROI, unknown
classCounts = zeros(numClasses,1) ;

for i = 1:numel(segTrain)
  fprintf('%s: computing segmentation stats for training image %d\n', mfilename, i) ;
  lb = imread(fullfile([imdb.paths.segmentation] , [imdb.images.name{segTrain(i)}]));
  ok = lb < 255;
  % numclasses + 1 because 255 value for undefined
  classCounts = classCounts + accumarray(lb(ok(:))+1, 1, [numClasses 1]) ;
end
stats.classCounts = classCounts ;

% Image statistics
for t=1:numel(dataTrain)
  fprintf('%s: computing RGB stats for training image %d\n', mfilename, t) ;
  rgb = imread(fullfile( [imdb.paths.image], [imdb.images.name{dataTrain(t)}]));
  rgb = single(rgb) ;
  z = reshape(permute(rgb,[3 1 2 4]),3,[]) ;
  n = size(z,2) ;
  rgbm1{t} = sum(z,2)/n ;
  rgbm2{t} = z*z'/n ;
end
rgbm1 = mean(cat(2,rgbm1{:}),2) ;
rgbm2 = mean(cat(3,rgbm2{:}),3) ;

stats.rgbMean = rgbm1 ;
stats.rgbCovariance = rgbm2 - rgbm1*rgbm1' ;
