%REPLOT is a tool developed to avoid a bug in original model.
% If initprocess has enabled the 'plotstatistics' option, software hangs
% randomly and you have a nice MatLab crash. 
% We suspect the cause is some buggy relationship between java libraries 
% and matlab ones. 
% If you don't need interactive plotting while learning process is in 
% execution just set 'plotstatistics' to false and this function will 
% recover your graph and named it 'replot-net-train.pd'  
function replot(folder, varargin)
opts.visible = true;
opts = vl_argparse(opts, varargin) ;

 start;
 epoch = findLastCheckpoint(folder);
 modelPath = @(ep) fullfile(folder, sprintf('net-epoch-%d.mat', ep));
 modelFigPath = fullfile(folder, 'replot-net-train.pdf') ;
[~, ~, stats] = loadState(modelPath(epoch)) ;
  
    Handler = figure ; clf ;
    if ~opts.visible, set(Handler, 'Visible', 'off'), end
    plots = setdiff(...
      cat(2,...
      fieldnames(stats.train)', ...
      fieldnames(stats.val)'), {'num', 'time'}) ;
    for p = plots
      p = char(p) ;
      values = zeros(0, epoch) ;
      leg = {} ;
      for f = {'train', 'val'}
        f = char(f) ;
        if isfield(stats.(f), p)
          tmp = [stats.(f).(p)] ;
          values(end+1,:) = tmp(1,:)' ;
          leg{end+1} = f ;
        end
      end
      subplot(1,numel(plots),find(strcmp(p,plots))) ;
      plot(1:epoch, values','o-') ;
      xlabel('epoch') ;
      title(p) ;
      legend(leg{:}) ;
      grid on ;
    end
    drawnow ;
    print(Handler, modelFigPath, '-dpdf') ;
   
 
 
% -------------------------------------------------------------------------
function epoch = findLastCheckpoint(folder)
% -------------------------------------------------------------------------
list = dir(fullfile(folder, 'net-epoch-*.mat')) ;
tokens = regexp({list.name}, 'net-epoch-([\d]+).mat', 'tokens') ;
epoch = cellfun(@(x) sscanf(x{1}{1}, '%d'), tokens) ;
epoch = max([epoch 0]) ;


% -------------------------------------------------------------------------
function [net, state, stats] = loadState(fileName)
% -------------------------------------------------------------------------
load(fileName, 'net', 'state', 'stats') ;
net = dagnn.DagNN.loadobj(net) ;
if isempty(whos('stats'))
  error('Epoch ''%s'' was only partially saved. Delete this file and try again.', ...
        fileName) ;
end