%SETUP reads image data snd setups IMDB file
% Function is called from INITPROCESS to load data at imdb
function imdb = setup(varargin)

% Load vlfeat and matconvnet tools
start;

opts.train = [];
opts.validation = [];
opts.segTrain = [];
opts.segVal = [];
opts.sourcePath = [];
opts.segmentationPath = [];


opts = vl_argparse(opts, varargin) ;

% path to source images and their segmentations
imdb.paths.image = opts.sourcePath ;
imdb.paths.segmentation = opts.segmentationPath ;

% define image subSets
imdb.sets.id = uint8([1 2]) ;
imdb.sets.name = {'train', 'val'} ;

imdb.classes.id = uint8(1) ;
imdb.classes.name = {'background','mole'};
imdb.classes.images = cell(1,2) ;

imdb.images.id = [] ;
imdb.images.name = {} ;
imdb.images.set = [] ;
imdb.images.path = {};

index = containers.Map() ;

% generate random index to shuffle data

%opts.train = opts.train(randperm(numel(opts.train)));
%opts.validation = opts.validation(randperm(numel(opts.validation)));

%  Add train and val data set

[imdb, index] = addImageSet(opts.train, imdb, index, 1) ;
[imdb, index] = addImageSet(opts.validation, imdb, index, 2) ;

%  Add train and val segmentation set

%[imdb, index] = addSegmentationSet(opts.segTrain, imdb, index, 1, rndidx1) ;
%[imdb, index] = addSegmentationSet(opts.segVal, imdb, index, 2, rndidx2) ;

% data and segmentation set must have same size. 
assert(numel(opts.train) == numel(opts.segTrain),...
    'Train: data and segmentation files do not match\n');
assert(numel(opts.validation) == numel(opts.segVal),...
    'Validation: data and segmentation files do not match\n');

% Compress data types
imdb.images.id = uint32(imdb.images.id) ;
imdb.images.set = uint8(imdb.images.set) ;
imdb.classes.images{1} = uint32(imdb.classes.images{1}) ;

% Check images on disk and get their size
imdb = getImageSizes(imdb) ;

% -------------------------------------------------------------------------
function [imdb, index] = addImageSet(nameList, imdb, index, setCode)
% -------------------------------------------------------------------------
j = length(imdb.images.id) ;

if setCode == 1, fprintf('---- Adding training set ----\n');
elseif setCode == 2, fprintf('---- Adding validation set ----\n');
else, error('%s unknown set: %d', mfilename, setCode);
end

for i=1:length(nameList)
    if ~index.isKey(nameList{i})
      j = j + 1 ;
      fprintf('Reading %s\n',  nameList{i}) ;
      index(nameList{i}) = j ;
      imdb.images.id(j) = j ;
      imdb.images.set(j) = setCode ;
      imdb.images.name{j} = nameList{i} ;
      imdb.images.classification(j) = true ;
      imdb.images.segmentation(j) = true ;
      imdb.images.path{j} = imdb.paths.image;
    else
      j = index(nameList{i}) ;
    end
end

% -------------------------------------------------------------------------
function imdb = getImageSizes(imdb)
% -------------------------------------------------------------------------
for j=1:numel(imdb.images.id) 
  
  info = imfinfo(fullfile([imdb.images.path{j}],[imdb.images.name{j}]));
  imdb.images.size(:,j) = uint16([info.Width ; info.Height]) ;
  fprintf('%s: checked image %s [%d x %d]\n', mfilename, imdb.images.name{j}, info.Height, info.Width) ;
end
