function [imgcellarray] = augmentimglist( folder, varargin )
%RESCALE rescale input image 
% Function reads all images from source folder.
% 'Rotate' enabled made 4 possible rotations and saved them to file. 
% 'Flip'  generate another image by mirroring. It is posible to 
% combine flip + rotate getting a total of 8 images from original one.

% Usage example:
% myArray = augmentimglist('folder', 'write2file', true, 'rotate',...
%           true)
% generate cell array of 4 rotated images for each original one and saving this 
% images to 'folder/resized'.

imgcellarray = {};

% Options structure

% 'write2file' disable this option if you only need an image array but not 
% image files.

% 'rotate' enable rotation data augmentation. ( 4 possible rotations of 90
% degrees)

% 'flip' enables mirroring data augmentation.

opts = struct(...
    'write2file', true,...
    'rotate', true,...
    'flip', true);

opts = vl_argparse(opts, varargin);

datalist = listFolder(folder);% read images from source data folder

targetDataFolder = fullfile(folder, 'augment');

cmap = [1 0 0; 0 0 0; 0 0 1];

if ~exist(targetDataFolder, 'dir') && opts.write2file
    mkdir(targetDataFolder); 
end

for i=1:numel(datalist)
    nameData = fullfile(folder, datalist(i));
    img = imread(nameData{1});
      
    [~, name, ext] = fileparts(nameData{1});
    % If image is grayscale (1 channel) image concatenate must be done over
    % 3th dimension. If it is RGB must be done over 4th dim.
    d = size(img,3);
    if d == 1, dim = 3; elseif d==3, dim = 4; end
              
    if opts.rotate       
        %  4 posible rotations.
        for j = 1:4
            img = uint8(rot90(img));
            targetFileData = fullfile(targetDataFolder,...
                [name '_rot_' int2str(j) ext]);
            
            imgcellarray = cat(dim, imgcellarray, img);
                     
            if opts.write2file, imwrite(img, targetFileData); end
            
            if opts.flip
                img = img(:,end:-1:1,:);
                targetFileData = fullfile(targetDataFolder,...
                    [name '_rot_' int2str(j) '_flip' ext]);
                
                imgcellarray = cat(dim, imgcellarray, img);
                
                if opts.write2file, imwrite(img, targetFileData);end
            end             
        end
     else
        targetFileData = fullfile(targetDataFolder, [name ext]);
        
        imgcellarray = cat(dim, imgcellarray, img);
        
        if opts.write2file, imwrite(img, targetFileData);end
        if opts.flip
            targetFileData = fullfile(targetDataFolder, [name '_flip' ext]);
            imgcellarray = cat(dim, imgcellarray, img);
            if opts.write2file, imwrite(img, targetFileData);end
        end
    end
end



