/*
 * fyrandperm_mex.c
 * Called by fyrandperm.m as y = fyrandperm_mex(x, rand(size(x)))
 *
 * Joakim Lbeck, 2001-06-21
 */

#include <math.h>
#include "mex.h"

#define	X_IN	prhs[0]
#define	R_IN	prhs[1]
#define	Y_OUT	plhs[0]


void mexFunction(int nlhs, mxArray *plhs[], 
		 int nrhs, const mxArray*prhs[])
{
	double *y, *r, t;
	int n, i, j;

	if (nrhs < 2)
	{ 
		mexErrMsgTxt("Two input arguments required."); 
	}
	else if (nlhs > 1)
	{
		mexErrMsgTxt("Too many output arguments."); 
	} 


	if (!mxIsDouble(X_IN) || mxIsComplex(X_IN))
		mexErrMsgTxt("x must be real and double");

	n = mxGetNumberOfElements(X_IN);
	if (n != mxGetNumberOfElements(R_IN))
		mexErrMsgTxt("r must have same size as x");
		
	if (!mxIsDouble(R_IN) || mxIsComplex(R_IN))
		mexErrMsgTxt("r must be real and double");

	Y_OUT = mxDuplicateArray(X_IN);

	y = mxGetPr(Y_OUT);
	r = mxGetPr(R_IN); 

	for (i = n-1; i >= 0; i--)
	{
		j = (int) floor((i+1) * r[i]);
		if (i != j)
		{
			t = y[i];
			y[i] = y[j];
			y[j] = t;
		}
	}

	return;
}
