function n = mancrop()
%MANCROP manually crops ROI of source image 

% Cropped images are saved to crop folder.
% source image without cropped ROI are saved as "current.png" load this
% image to resume process.

% use index to set starting label for cropped regions.
index = 1;
fprintf('label start at: %d\n',index);

% Change the current folder to the folder of this m-file.
if(~isdeployed)
	cd(fileparts(which(mfilename)));
end
clc;	% Clear command window.
close all;	% Close all figure windows except those created by imtool.
imtool close all;	% Close all figure windows created by imtool.
workspace;	% Make sure the workspace panel is showing.
fontSize = 16;

% Get parent folder
parentpath = cd(cd('..'));

% Make general output and target folders.
root = fullfile( parentpath, 'root_folder');
if ~exist(root, 'dir'), mkdir(root); end

% make general output folder 
outputFolder = fullfile(root, 'output');
if ~exist(outputFolder, 'dir'), mkdir(outputFolder); end

% make targetFolder
targetFolder = fullfile( outputFolder, 'imgcrop');
if ~exist(targetFolder, 'dir'), mkdir(targetFolder); end

% Let user select file.
count = fprintf('Select image\n');
[filename, path, ~] =  uigetfile(...
	fullfile(...
	pwd,'*.jpg;*.png;*.bmp'),...
	'Select image');
fprintf(1, repmat('\b',1,count)); %delete line before
fprintf('Image: %s\n', filename);

% Get the full filename.
fullFileName = fullfile(path, filename);

%read and plot image
img = imread(fullFileName);
h_im = imshow(img, []);
axis on;
title('Original Image', 'FontSize', fontSize);
set(gcf, 'Position', get(0,'Screensize')); % Maximize figure.

% set status to control execution flow
status = 0;
% set flag for help message 
messageFlag = true;
while status ~= 1
    message = 'Select area, hold right mouse button and choose crop from menu';
    if messageFlag
        uiwait(msgbox(sprintf(message)));
    end;
    
    % use imcrop tool to get cropped area
	[croppedImg, rect] = imcrop(h_im);
    
    % draw rectangle over cropped area and get handler
    e = imrect(gca,rect);
    
    % make binary mask of source cropped image 
    bw = createMask(e, h_im);
    hold on;
    
	%Construct a questdlg with three options
	choice = questdlg('Selected area has been cropped, continue or redo?', ...
		'Crop area', ...
		'End', 'Redo', 'Continue', 'Continue');

	% Handle response
	switch choice
		case 'End'
            close all;
			return;
        case 'Redo'
            delete(e);
            status = 0;
            messageFlag = false;
            
        case 'Continue'
            % store cropped area and increase index
            [~, name, ~] = fileparts(filename);
            str = sprintf('%04d',index);
            cropfile = fullfile(targetFolder, [name '_crop' str '.png']);
            imwrite(croppedImg, cropfile);
            
            % get negative mask
            mask = uint8(~bw);
            
            % get source image without cropped area
            newImg = repmat(mask,[1,1,3]).* img; 
            
            %label cropped area
            newImg = insertText(newImg, [rect(1) rect(2)], int2str(index));
            imwrite(newImg, fullfile(targetFolder,[name '_labels.png']));
            index = index + 1;
           
            % update image 
            img = newImg;
            imshow(img);
            status = 0;
            messageFlag = false;
	end
end
n = index; % return number of processed images
close;