function n = mansegment()
%MANSEGMENT allow user to do ROI manual segmentation. 

% Change the current folder to the folder of this m-file.
if(~isdeployed)
	cd(fileparts(which(mfilename)));
end
clc;	% Clear command window.
clear;	% Delete all variables.
close all;	% Close all figure windows except those created by imtool.
imtool close all;	% Close all figure windows created by imtool.
workspace;	% Make sure the workspace panel is showing.
fontSize = 16;

% Get parent folder
parentpath = cd(cd('..'));

% Get current folder
startfolder = pwd;

% Make general output and target folders.
root = fullfile( parentpath, 'root_folder');
if ~exist(root, 'dir'), mkdir(root); end

% make general output folder 
outputFolder = fullfile(root, 'output');
if ~exist(outputFolder, 'dir'), mkdir(outputFolder); end

% make targetFolder
targetFolder = fullfile( outputFolder, 'imgsegment');
if ~exist(targetFolder, 'dir'), mkdir(targetFolder); end

% Let user select file.
outputfile = [];
[img, filename] = loadFile(outputfile);

% Next time we can launch file loading from same folder. 
[currentFolder, ~, ~] = fileparts(filename);

% set first cell array position
index = 1;
% set status to control execution flow
status = 0;
% set flag for help message 
messageFlag = true;

while status ~= 1

    h_im = imshow(img, 'InitialMagnification','fit');
    axis on;
    title('Original Image', 'FontSize', fontSize);
    set(gcf, 'Position', get(0,'Screensize')); % Maximize figure.
    message = 'Left click and hold to begin drawing.\nlift the mouse button to finish';
    if messageFlag
        uiwait(msgbox(sprintf(message)));
    end;
    
    hFH = imfreehand(); % Actual line of code to do the drawing.
    % Create a binary image ("mask") from the ROI object.
    binaryImage = hFH.createMask();
    xy = hFH.getPosition;

    subplot(221);
    imshow(img, []);
    axis on;
    drawnow;
    title('Original image', 'FontSize', fontSize);
    
    % Display the freehand mask.
    subplot(222);
    imshow(binaryImage);
    axis on;
    title('Binary mask of the ROI', 'FontSize', fontSize);
        % Get coordinates of the boundary of the freehand drawn region.
        structBoundaries = bwboundaries(binaryImage);
        xy=structBoundaries{1}; % Get n by 2 array of x,y coordinates.
        x = xy(:, 2); % Columns.
        y = xy(:, 1); % Rows.
        subplot(2, 2, 1); % Plot over original image.
        hold on; % Don't blow away the image.
        plot(x, y, 'LineWidth', 2);
        drawnow; % Force it to draw immediately.
    
    % Construct a questdlg with three options
	choice = questdlg(' Segmentation will be saved as binary mask, save or redo?', ...
		'Segmentation', ...
		'End', 'Redo', 'Save', 'Save');

	% Handle response
	switch choice
		case 'End'
            cd (startfolder);
            clf;
            close;
			return;
            
        case 'Redo'
            clf;
            status = 0;
            messageFlag = false;
            
        case 'Save'
            % save segmentation
            [path, name, ext] = fileparts(filename);
            segmentation = uint8(binaryImage);
            outputFile = fullfile(targetFolder, [name '_segmentation' ext]);
            if ~exist(outputFile, 'file')
                imwrite(segmentation, outputFile);
            else
                choice2 = questdlg(' File exist, overwrite?', 'save file',...
                    'Yes, do it', 'No', 'No');
                if strcmp(choice2, 'Yes, do it')
                    imwrite(segmentation, outputFile)
                end  
            end
            
            % Allow user to process more files
            
            choice1 = questdlg(' Done!, more files?', ...
                'Save file',...
                'No thanks', 'Yes', 'No thanks');
            if strcmp(choice1, 'No thanks')
                status = 1;
            elseif strcmp(choice1, 'Yes')
                clf;
                cd(currentFolder);                             
                [img, filename] = loadFile(name);
                [currentFolder, ~, ~] = fileparts(filename);
                status = 0;
            end                  
    end
end
cd (startfolder);
clf;
close;
return;


%--------------------------------------------------------------------------
% load image 
%--------------------------------------------------------------------------

function [img, file] = loadFile(previous)
    message = ['Previous:' previous];
    count = fprintf('Select image\n');
    [filename, path, ~] =  uigetfile(fullfile( pwd,'*.jpg;*.png;*.bmp'),...
        message);
    fprintf(1, repmat('\b',1,count)); %delete line before
    fprintf('Image: %s\n', filename);

    % Get the full filename.
    file = fullfile(path, filename);

    %read image
    img = imread(file);





 