function img = overlay_seg(rgbpath,segpath)
%OVERLAY_SEG is an auxiliar function used to overlap predictions and 
% ground-truth over source image.

% read directory struct
dataList = listFolder(rgbpath);% read images from source data folder
segmentationList = listFolder(segpath);


if isempty(dataList)
    error('%s: no files at %d\n', mfilename, opts.paths.sourceData); 
end
if isempty(segmentationList)
    error('%s: no files at %d\n', mfilename, opts.paths.sourceSeg);
end

assert(numel(dataList)==numel(segmentationList));
for i=1:numel(dataList)
    
    nameData = fullfile(rgbpath, dataList(i));
    nameSeg = fullfile(segpath, segmentationList(i));
    rgb = imread(nameData{1});
    seg = imread(nameSeg{1});
    assert(size(rgb,1)==size(seg,1));
    assert(size(rgb,2)==size(seg,2));
    assert(size(seg,3)==1);
    assert(size(rgb,3)==3);

    
    % Get perimeter;
    segPerimeter= bwperim(seg*255);

    % set color for segmentation 
    segcolor = [0,255,0];
    R_channel = rgb(:,:,1);
    G_channel = rgb(:,:,2);
    B_channel = rgb(:,:,3);

    R_channel(segPerimeter) = segcolor(1);
    G_channel(segPerimeter) = segcolor(2);
    B_channel(segPerimeter) = segcolor(3);

    img = cat(3, R_channel, G_channel, B_channel);
    imshow(img, 'InitialMagnification','fit');
    fprintf('%s\n',nameData{1});
    w = waitforbuttonpress;
    close all;
    
end


