%RES resize all images from selected folder.

% Select souce folder
% options

% size: set the minimum size of the image. if you select 128 and you have
% an 136 x 192 image you get 128x181 image wich manteins the same aspect 
% ratio as original file. if you have 192x136 image you have 181x128 image.

% crop: select this option if you need square images. for the last example 
% selecting 128 and crop you get 128x128 images by cropping outer area.
% For 136x192 you get 128 x 182 resizing dim1 to 128, manteining aspect
% ratio and cropping first and last columns of image until 128x128 size is
% reached.

% w2f: enable this option if you need files been writed to a folder.
% otherwise you have your images in memory as imgarray.

function [imgarray] = res( )

global w2f;
global crop;
global imgsize;

% write to file option
w2f = 0;
% crop to square image
crop = 0;
% size of bigger side
imgsize = 64;

folder =  uigetdir((pwd), 'Select folder');
choosedialog();

% output array for cropped square images
imgarray = [];

% output cell array for source aspect ratio preserved images
imgcellarray = {};

% read images from source data folder
datalist = listFolder(folder);

% set output folder
if w2f
    outputFolder = fullfile(folder, 'resized');
    if ~exist(outputFolder, 'dir'), mkdir(outputFolder); end 
end

% resize and crop each image
for i=1:numel(datalist)
    nameData = fullfile(folder, datalist(i));
    dataImg = imread(nameData{1});
    [h,w,depth] = size(dataImg) ;
    
    % If image is grayscale (1 channel) image concatenate must be done over
    % 3th dimension. If it is RGB must be done over 4th dim.
    if depth == 1, dim = 3; else, dim = 4; end
    
    if h<w
        output = imresize(dataImg, [imgsize NaN]);
        if crop
            % crop to get square image 
            [~,w1,~] = size(output);
            
            % if grayscale
            if depth == 1
                output = ...
                    output(:,floor((w1/2 - imgsize/2)+1:(w1/2 + imgsize/2)));
            else
                output = ...
                    output(:,floor((w1/2 - imgsize/2)+1:(w1/2 + imgsize/2)),:);
            end
                
        end
    else       
        output = imresize(dataImg, [NaN imgsize]);
        if crop
            % crop to get square image 
            [h1,~,~] = size(output);
            if depth == 1
                output = ...
                    output(floor((h1/2 - imgsize/2)+1:(h1/2 + imgsize/2)),:);
            else
                
                output = ...
                    output(floor((h1/2 - imgsize/2)+1:(h1/2 + imgsize/2)),:,:);
            end
        end
    end
    output = uint8(output);
    if crop
        imgarray = cat(dim, imgarray, output); 
    else
        imgcellarray = cat(dim, imgcellarray, output);
    end
    [~, name, ext] = fileparts(nameData{1});
    if w2f    
        outputname = fullfile(outputFolder, [name ext]);
        output = uint8(output);
        if depth==1
            cmap = [1 0 0; 0 0 0; 0 0 1];
            imwrite(uint8(output), cmap, outputname);
        else
            imwrite(uint8(output), outputname);
        end
    end
end
if ~crop, imgarray = imgcellarray; end


function choosedialog
    
       
    d = dialog('Position',[300 300 250 180],'Name','Select options');
    movegui(d,'center');
    
    txt1 = uicontrol('Parent',d,...
           'Style','text',...
           'Position',[20 130 210 30],...
           'String','Select size');
       
    edit1 = uicontrol('Parent', d,...
            'Style','edit',...
            'Position',[75 100 90 35],...
            'String','64',...
            'Callback', @edit1_callback);
       
    checkbox1 = uicontrol('Parent',d,...
           'Style','checkbox',...
           'Position',[75 70 90 25],...
           'String', 'Crop',...
           'Callback',@checkbox1_callback);
       
    btn = uicontrol('Parent',d,...
           'Position',[129 20 70 25],...
           'String','Go!',...
           'Callback','delete(gcf)');
       
    btn1 = uicontrol('Parent',d,...
           'Position',[49 20 70 25],...
           'String', 'Cancel',...
           'Callback',@cancel_callback);
       
    checkbox2 = uicontrol('Parent',d,...
           'Style','checkbox',...
           'String', 'Write to file',...
           'Value',0,...
           'Position', [75 50 100 25],...
           'Callback',@checkbox2_callback);
      
    
       
    % Wait for d to close before running to completion
    uiwait(d);
    
   
       function cancel_callback(btn1, event)
           delete(gcf);
           Disp('End');
          
       function checkbox1_callback(checkbox1, event)
          global crop
          crop = checkbox1.Value;
          
       function checkbox2_callback(checkbox2, event)
          global w2f
          w2f = checkbox2.Value;

       function edit1_callback(edit1, event)
            
          global imgsize 
          imgsize = str2double(get(edit1,'String'));
          return;

      