function [imgarray] = resizeimglist( folder, value, varargin )
%RESIZEIMGLIST resize all input images from folder 
% Function reads all images from source folder. 
% If crop flag is enabled images are resized and cropped to square 
% value x value image.
% If crop flag is disabled images are resized, keeping aspect ratio,
% setting the lower dimension as input value.

% Use example: resizeimglist('/folder/img', 256, true);
% resizes all images from '/folder/img' to 256 x 256 using crop. 


% output array for cropped square images
imgarray = [];

% output cell array for source aspect ratio preserved images
imgcellarray = {};

% Set this input parameter to true if you need resized images saved at disk.
% but do not change this value here.
opts.write2file = false;

% Set this input parameter to false if you need to keep source aspect ratio
% but do not change this value here.
opts.crop = true;

% Parse input parameters
opts = vl_argparse(opts, varargin);

 % read images from source data folder
datalist = listFolder(folder);

% set output folder
if opts.write2file
    outputFolder = fullfile(folder, 'resized');
    if ~exist(outputFolder, 'dir'), mkdir(outputFolder); end 
end

% resize and crop each image
for i=1:numel(datalist)
    nameData = fullfile(folder, datalist(i));
    dataImg = imread(nameData{1});
    [h,w,depth] = size(dataImg) ;
    
    % If image is grayscale (1 channel) image concatenate must be done over
    % 3th dimension. If it is RGB must be done over 4th dim.
    if depth == 1, dim = 3; else, dim = 4; end
    
    if h<w
        output = imresize(dataImg, [value NaN]);
        if opts.crop
            % crop to get square image 
            [~,w1,~] = size(output);
            
            % if grayscale
            if depth == 1
                output = ...
                    output(:,floor((w1/2 - value/2)+1:(w1/2 + value/2)));
            else
                output = ...
                    output(:,floor((w1/2 - value/2)+1:(w1/2 + value/2)),:);
            end
                
        end
    else       
        output = imresize(dataImg, [NaN value]);
        if opts.crop
            % crop to get square image 
            [h1,~,~] = size(output);
            if depth == 1
                output = ...
                    output(floor((h1/2 - value/2)+1:(h1/2 + value/2)),:);
            else
                
                output = ...
                    output(floor((h1/2 - value/2)+1:(h1/2 + value/2)),:,:);
            end
        end
    end
    output = uint8(output);
    if opts.crop
        imgarray = cat(dim, imgarray, output); 
    else
        imgcellarray = cat(dim, imgcellarray, output);
    end
    [~, name, ext] = fileparts(nameData{1});
    if opts.write2file    
        outputname = fullfile(outputFolder, [name ext]);
        output = uint8(output);       
        imwrite(uint8(output), outputname);
    end
end
if ~opts.crop, imgarray = imgcellarray; end

