% Auxiliar function used in osme tessellation and slicing experiments. 
% you don't need it

opts.root = 'root_folder' ;

% folder with all image files
opts.paths.dataset = fullfile(opts.root, 'dataset') ;

% Location of training source images and their segmentations.
opts.paths.source = fullfile(opts.root, 'dataset', 'source');
opts.paths.sourceData = fullfile(opts.paths.source, 'data') ;
opts.paths.sourceSeg = fullfile( opts.paths.source, 'segmentation') ;
opts.paths.results = fullfile(opts.paths.source, 'slice');
opts.paths.resultData = fullfile(opts.paths.results, 'data');
opts.paths.resultSeg = fullfile(opts.paths.results, 'segmentation');

if ~exist(opts.paths.results, 'dir'), mkdir(opts.paths.results);end;
if ~exist(opts.paths.resultData, 'dir'), mkdir(opts.paths.resultData);end;
if ~exist(opts.paths.resultSeg, 'dir'), mkdir(opts.paths.resultSeg);end;

source = listFolder(opts.paths.sourceData);
segmentation = listFolder(opts.paths.sourceSeg);

% get actual size (h,w) of image.
for i=1:numel(source)
    nameData = fullfile(opts.paths.sourceData, source(i));
    srcImg = imread(nameData{1});
    [h,w,~] = size(srcImg) ;
    nameSeg = fullfile(opts.paths.sourceSeg, segmentation(i));
    srcSeg = imread(nameSeg{1});
    %if ~islogical(srcSeg), srcSeg = logical(mod(srcSeg, 2)); end;
     if islogical(srcSeg), srcSeg = uint8(srcSeg *255); end;
    % check data and segmentation sizes matching
    [h1,w1,~] = size(srcSeg) ;
    assert((h==h1) && (w == w1),...
        'Source and segmentation data has different size');
    
    % Pad source and seg file to be multiple of 384. ( net needs 384 x 384
    % images).
    h_blocks = ceil(h/384);
    w_blocks = ceil(w/384);
    s1 = 384 * h_blocks;
    s2 = 384 * w_blocks;
    p1 = s1-h;
    p2 = s2-w;
    
    paddedImg = padarray(srcImg, [p1 p2], 'post');
    paddedSeg = padarray(srcSeg, [p1 p2], 0, 'post');
    
    % get dimension 1 and 2 of padded image
    dim1 = repmat (384, 1, h_blocks);
    dim2 = repmat (384, 1, w_blocks);
    
    % 
    cellImg = mat2cell(paddedImg, dim1, dim2, 3);
    cellImg = reshape(cellImg, 1, h_blocks*w_blocks);
    cellSeg =  mat2cell(paddedSeg, dim1, dim2);
    cellSeg = reshape(cellSeg, 1,h_blocks*w_blocks);
    
    for i=1:numel(cellImg)
        [pathstr,name,ext] = fileparts(nameData{1}) ;
        imwrite(cellImg{i}, fullfile(opts.paths.resultData, [name '-' int2str(i) ext]));
        [pathstr1,name1,ext1] = fileparts(nameSeg{1}) ;
        imwrite(cellSeg{i}, fullfile(opts.paths.resultSeg, [name '-' int2str(i) '-segmentation' ext]));
    end;
end;